# SUS02-BP05: Optimize team member resources

## Description

Reduce carbon từ team activities.

## Implementation Guidance

- Enable remote work
- Reduce business travel
- Use virtual meetings
- Optimize office energy
- Track team carbon footprint

## Risk Level

Low - Team activities also contribute to carbon.

## Related Best Practices

- [SUS02-BP04](SUS02-BP04-Geographic-Placement.md)
- [OPS03-BP02](../../01-OPS/OPS03-Organization-Organizational-Culture/OPS03-BP02-Team-Members-Empowered.md)
